<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>Aide</name>
    <message>
        <location filename="../Ui_help.py" line="153"/>
        <source>Aide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="152"/>
        <source>Mode d&apos;emploi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="155"/>
        <source>ScolaSync, pour gerer les fichiers des baladeurs</source>
        <translation>ScolaSync, pour gérer les fichiers des baladeurs</translation>
    </message>
    <message>
        <location filename="" line="5570656"/>
        <source>Numero de version&#xa0;:</source>
        <translation type="obsolete">Numéro de version :</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="157"/>
        <source>Auteurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="158"/>
        <source>Licence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="159"/>
        <source>Langues et traductions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="160"/>
        <source>A propos</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="161"/>
        <source>Fermer</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_help.py" line="156"/>
        <source>Numero de version :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="154"/>
        <source>Manuel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="" line="5570656"/>
        <source>Choix des fichiers &#xe0; copier</source>
        <translation type="obsolete">Choix des fichiers à copier</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="175"/>
        <source>/</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="176"/>
        <source>Ordinateur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="178"/>
        <source>Disque dur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="198"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="184"/>
        <source>Baladeur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="187"/>
        <source>Disque flash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="190"/>
        <source>Cle USB</source>
        <translation>Clé USB</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="194"/>
        <source>Ajouter a la liste</source>
        <translation>Ajouter à la liste</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="197"/>
        <source>Retirer de la liste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="199"/>
        <source>Abandonner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="200"/>
        <source>Continuer ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="282"/>
        <source>Double-clic non pris en compte</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="485"/>
        <source>Veuillez choisir au moins un fichier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="481"/>
        <source>Choix de la destination ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="524"/>
        <source>Voir les copies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="532"/>
        <source>Destination manquante</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="532"/>
        <source>Veuillez choisir une destination pour la copie des fichiers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_chooseInSticks.py" line="143"/>
        <source>Zone de recherche</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_chooseInSticks.py" line="165"/>
        <source>Rechercher (fichier) ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_preferences.py" line="119"/>
        <source>Preferences de ScolaSync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_preferences.py" line="120"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../Ui_preferences.py" line="128"/>
        <source>Travail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copyToDialog1.py" line="164"/>
        <source>%s kilo-octets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copyToDialog1.py" line="170"/>
        <source>%s giga-octets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ownedUsbDisk.py" line="170"/>
        <source>inconnu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ownedUsbDisk.py" line="212"/>
        <source>La cle %1&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
        <translation type="obsolete">La clé %1&lt;br&gt;n&apos;est pas identifiée, donnez le nom du propriétaire</translation>
    </message>
    <message>
        <location filename="../ownedUsbDisk.py" line="213"/>
        <source>Entrer un nom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="430"/>
        <source>Vous allez effacer plusieurs baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="142"/>
        <source>Choix de fichiers à supprimer</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="144"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Répertoire des &lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;documents de &lt;br /&gt;travail&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="150"/>
        <source>Le répertoire des clés&lt;br&gt;où se trouvent les&lt;br&gt;documents de travail</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="151"/>
        <source>Le répertoire des clés où se trouvent les documents de travail</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="152"/>
        <source>Choix de clé modèle</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="154"/>
        <source>Choisir une des clés</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="155"/>
        <source>Liste de fichiers à traiter (jokers autorisés)</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="157"/>
        <source>Supprimer l&apos;item sélectionné</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="168"/>
        <source>Rechercher (répertoire) ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="122"/>
        <source>Les cases à cocher permettent de n&apos;agir que sur une part des baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="123"/>
        <source>Utiliser des cases à cocher pour désigner les baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="127"/>
        <source>Répertoire pour les travaux :</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_copyToDialog1.py" line="174"/>
        <source>Choix des fichiers à copier</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_copyToDialog1.py" line="180"/>
        <source>Répertoire de destination des baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_copyToDialog1.py" line="182"/>
        <source>Répertoire de destination sur les baladeurs,&lt;br&gt;peut être modifié dans les préférences</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_copyToDialog1.py" line="192"/>
        <source>Taille totale :</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="423"/>
        <source>Choix de fichiers à supprimer (jokers autorisés)</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="485"/>
        <source>Aucun fichier sélectionné</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="479"/>
        <source>Choix de fichiers à copier</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="480"/>
        <source>Choix de fichiers à copier depuis les baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="493"/>
        <source>Choisir un répertoire de destination</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="524"/>
        <source>Voulez-vous voir les fichiers copiés ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../copyToDialog1.py" line="167"/>
        <source>%s méga-octets</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="129"/>
        <source>Fichier spécial pour le manuel :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_preferences.py" line="130"/>
        <source>/usr/share/scolasync/help/manualPage_fr_FR.html</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="131"/>
        <source>Recomptage automatique des médias :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_preferences.py" line="132"/>
        <source>toutes les</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_preferences.py" line="133"/>
        <source>30 secondes</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="163"/>
        <source>Ligne d&apos;édition du nom d&apos;un fichier ou d&apos;un répertoire.&lt;br&gt;Jokers autorisés</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="160"/>
        <source>Ajouter un fichier ou un filtre défini dans la ligne d&apos;édition</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="555"/>
        <source>Réitérer la dernière commande</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="126"/>
        <source>Efface les fichiers et les répertoires après copie</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="124"/>
        <source>Si la case est cochée,&lt;br&gt;les données sont transférées sur le disque dur&lt;br&gt;puis effacée des baladeurs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="125"/>
        <source>Si la case est cochée, les données sont transférées sur le disque dur puis effacée des baladeurs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_choixEleves.py" line="117"/>
        <source>Choix d&apos;un groupe d&apos;élèves</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_choixEleves.py" line="120"/>
        <source>Actions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_choixEleves.py" line="121"/>
        <source>Replier toutes les classes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_choixEleves.py" line="122"/>
        <source>Tout replier</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_choixEleves.py" line="123"/>
        <source>Cocher tous les élèves visibles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_choixEleves.py" line="124"/>
        <source>Cocher</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_choixEleves.py" line="125"/>
        <source>Décocher tous les élèves, visibles ou non</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_choixEleves.py" line="126"/>
        <source>Décocher</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_choixEleves.py" line="128"/>
        <source>Ajout à la liste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_choixEleves.py" line="130"/>
        <source>Suppr. de la liste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_choixEleves.py" line="135"/>
        <source>Valider</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_choixEleves.py" line="132"/>
        <source>N° à partir de</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_choixEleves.py" line="131"/>
        <source>Quand la case est cochée, un numéro sera ajouté comme préfixe aux noms</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_choixEleves.py" line="133"/>
        <source>La numérotation commence à cette valeur</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_choixEleves.py" line="127"/>
        <source>Ajouter les noms cochés de l&apos;arbre dans la liste à droite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_choixEleves.py" line="129"/>
        <source>Supprimer de la liste les noms en surbrillance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_choixEleves.py" line="134"/>
        <source>Accepter la liste actuelle et fermer ce dialogue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_choixEleves.py" line="136"/>
        <source>Supprimer tous les noms de la liste et fermer ce dialogue</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_choixEleves.py" line="137"/>
        <source>Remettre à zéro</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../ownedUsbDisk.py" line="70"/>
        <source>Choix du propriétaire</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../ownedUsbDisk.py" line="71"/>
        <source>Nouveau nom du propriétaire du baladeur</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_choixEleves.py" line="118"/>
        <source>Liste d&apos;élèves</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_choixEleves.py" line="119"/>
        <source>Ouvrir un fichier ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="134"/>
        <source>Fichier des élèves :</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_nameAdrive.py" line="72"/>
        <source>Nommer le baladeur nouvellement connecté</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_nameAdrive.py" line="73"/>
        <source>Changez le choix parmi cette liste si une autre ligne convient mieux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_nameAdrive.py" line="75"/>
        <source>nom actuel du baladeur</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_nameAdrive.py" line="76"/>
        <source>C&apos;est le nom connu par votre ordinateur, s&apos;il a déjà été défini dans le passé</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_nameAdrive.py" line="77"/>
        <source>nom proposé</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_nameAdrive.py" line="78"/>
        <source>Le nouveau nom proposé peut venir de la liste à gauche ou être modifié à la main</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_nameAdrive.py" line="79"/>
        <source>Renommer le baladeur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_nameAdrive.py" line="80"/>
        <source>Choisir comme nouveau nom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_nameAdrive.py" line="81"/>
        <source>Fermer le dialogue sans rien faire</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_nameAdrive.py" line="82"/>
        <source>Échappement</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../choixEleves.py" line="96"/>
        <source>Échec à l&apos;ouverture du fichier élèves</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ownedUsbDisk.py" line="212"/>
        <source>La cle {id}&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../choixEleves.py" line="96"/>
        <source>Le fichier {schoolfile} n&apos;a pas pu être traité : {erreur}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.py" line="55"/>
        <source>{t} secondes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="282"/>
        <source>pas d&apos;action pour l&apos;attribut {a}</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="555"/>
        <source>La dernière commande était&lt;br&gt;{cmd}&lt;br&gt;Voulez-vous la relancer avec les nouveaux baladeurs ?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context encoding="UTF-8">
    <name>Main</name>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="589"/>
        <source>Démontage des baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="589"/>
        <source>Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="808"/>
        <source>Propriétaire de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour modifier.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="810"/>
        <source>Point de montage de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir les fichiers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="812"/>
        <source>Capacité de la clé USB ou du baladeur en kO ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir la place occupée.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="814"/>
        <source>Fabricant de la clé USB ou du baladeur.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="816"/>
        <source>Modèle de la clé USB ou du baladeur.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="818"/>
        <source>Numéro de série de la clé USB ou du baladeur.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="806"/>
        <source>Cocher ou décocher cette case en cliquant.&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour agir sur plusieurs baladeurs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../help.py" line="43"/>
        <source>Version numéro {major}.{minor}</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../Ui_diskFull.py" line="56"/>
        <source>Disk size</source>
        <translation>Taille du disque</translation>
    </message>
    <message>
        <location filename="../Ui_diskFull.py" line="57"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_diskFull.py" line="58"/>
        <source>total size</source>
        <translation>taille totale</translation>
    </message>
    <message>
        <location filename="../Ui_diskFull.py" line="59"/>
        <source>Used</source>
        <translation>Utilisé(s)</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="149"/>
        <source>ScolaSync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="150"/>
        <source>Actions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="42"/>
        <source>Copier depuis les cles</source>
        <translation type="obsolete">Copier depuis les clés</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="54"/>
        <source>Copier vers les cles</source>
        <translation type="obsolete">Copier vers les clés</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="78"/>
        <source>Demonter les cles</source>
        <translation type="obsolete">Démonter les clés</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="90"/>
        <source>Preferences</source>
        <translation type="obsolete">Préférences</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="176"/>
        <source>Aide</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_mainWindow.py" line="170"/>
        <source>Force à recompter les baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_mainWindow.py" line="168"/>
        <source>Affiche le nombre de baladeurs connectés</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_mainWindow.py" line="173"/>
        <source>Préférences</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="203"/>
        <source>Refaire à nouveau</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="204"/>
        <source>Refaire à nouveau la dernière opération réussie, avec les baladeurs connectés plus récemment</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_mainWindow.py" line="161"/>
        <source>Éjecter les baladeurs sélectionnés</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_mainWindow.py" line="152"/>
        <source>Copier depuis les baladeurs sélectionnés</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_mainWindow.py" line="155"/>
        <source>Copier vers les baladeurs sélectionnés</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_mainWindow.py" line="158"/>
        <source>Effacer des fichiers ou des dossiers dans les baladeurs sélectionnés</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="205"/>
        <source>Arrêter les opérations en cours</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="206"/>
        <source>Essaie d&apos;arrêter les opérations en cours. À faire seulement si celles-ci durent trop longtemps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="81"/>
        <source>&lt;br /&gt;Des noms sont disponibles pour renommer les prochains baladeurs que vous brancherez</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="82"/>
        <source>&lt;br /&gt;Cliquez sur ce bouton pour préparer une liste de noms afin de renommer les prochains baladeurs que vous brancherez</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>checkBoxDialog</name>
    <message encoding="UTF-8">
        <location filename="../Ui_checkBoxDialog.py" line="55"/>
        <source>Gestion des cases à cocher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_checkBoxDialog.py" line="57"/>
        <source>Cocher tous les baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_checkBoxDialog.py" line="58"/>
        <source>Tout cocher</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_checkBoxDialog.py" line="60"/>
        <source>Inverser le choix de baladeurs&lt;br&gt;Les baladeurs cochés seront décochés, et inversement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_checkBoxDialog.py" line="61"/>
        <source>Inverser le choix</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_checkBoxDialog.py" line="63"/>
        <source>Désélectionner les baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_checkBoxDialog.py" line="64"/>
        <source>Ne rien cocher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Ui_checkBoxDialog.py" line="66"/>
        <source>Ne rien faire</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_checkBoxDialog.py" line="67"/>
        <source>Échappement</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context encoding="UTF-8">
    <name>diskFull</name>
    <message encoding="UTF-8">
        <location filename="../diskFull.py" line="51"/>
        <source>Place totale : {size} kilo-octets</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../diskFull.py" line="52"/>
        <source>Place utilisée : {size} kilo-octets</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>uDisk</name>
    <message>
        <location filename="../usbDisk.py" line="65"/>
        <source>point de montage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../usbDisk.py" line="66"/>
        <source>taille</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../usbDisk.py" line="72"/>
        <source>cocher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ownedUsbDisk.py" line="154"/>
        <source>owner</source>
        <translation>propriétaire</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../usbDisk.py" line="68"/>
        <source>modèle de disque</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../usbDisk.py" line="69"/>
        <source>numéro de série</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../usbDisk.py" line="67"/>
        <source>marque</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
